"""PyPA Topic Classifiers."""
choices = [
    'Adaptive Technologies',
    'Artistic Software',
    'Communications',
    'Communications :: BBS',
    'Communications :: Chat',
    'Communications :: Chat :: ICQ',
    'Communications :: Chat :: Internet Relay Chat',
    'Communications :: Chat :: Unix Talk',
    'Communications :: Conferencing',
    'Communications :: Email',
    'Communications :: Email :: Address Book',
    'Communications :: Email :: Email Clients (MUA)',
    'Communications :: Email :: Filters',
    'Communications :: Email :: Mail Transport Agents',
    'Communications :: Email :: Mailing List Servers',
    'Communications :: Email :: Post-Office',
    'Communications :: Email :: Post-Office :: IMAP',
    'Communications :: Email :: Post-Office :: POP3',
    'Communications :: FIDO',
    'Communications :: Fax',
    'Communications :: File Sharing',
    'Communications :: File Sharing :: Gnutella',
    'Communications :: File Sharing :: Napster',
    'Communications :: Ham Radio',
    'Communications :: Internet Phone',
    'Communications :: Telephony',
    'Communications :: Usenet News',
    'Database',
    'Database :: Database Engines/Servers',
    'Database :: Front-Ends',
    'Desktop Environment',
    'Desktop Environment :: File Managers',
    'Desktop Environment :: GNUstep',
    'Desktop Environment :: Gnome',
    'Desktop Environment :: K Desktop Environment (KDE)',
    'Desktop Environment :: K Desktop Environment (KDE) :: Themes',
    'Desktop Environment :: PicoGUI',
    'Desktop Environment :: PicoGUI :: Applications',
    'Desktop Environment :: PicoGUI :: Themes',
    'Desktop Environment :: Screen Savers',
    'Desktop Environment :: Window Managers',
    'Desktop Environment :: Window Managers :: Afterstep',
    'Desktop Environment :: Window Managers :: Afterstep :: Themes',
    'Desktop Environment :: Window Managers :: Applets',
    'Desktop Environment :: Window Managers :: Blackbox',
    'Desktop Environment :: Window Managers :: Blackbox :: Themes',
    'Desktop Environment :: Window Managers :: CTWM',
    'Desktop Environment :: Window Managers :: CTWM :: Themes',
    'Desktop Environment :: Window Managers :: Enlightenment',
    'Desktop Environment :: Window Managers :: Enlightenment :: Epplets',
    'Desktop Environment :: Window Managers :: Enlightenment :: Themes DR15',
    'Desktop Environment :: Window Managers :: Enlightenment :: Themes DR16',
    'Desktop Environment :: Window Managers :: Enlightenment :: Themes DR17',
    'Desktop Environment :: Window Managers :: FVWM',
    'Desktop Environment :: Window Managers :: FVWM :: Themes',
    'Desktop Environment :: Window Managers :: Fluxbox',
    'Desktop Environment :: Window Managers :: Fluxbox :: Themes',
    'Desktop Environment :: Window Managers :: IceWM',
    'Desktop Environment :: Window Managers :: IceWM :: Themes',
    'Desktop Environment :: Window Managers :: MetaCity',
    'Desktop Environment :: Window Managers :: MetaCity :: Themes',
    'Desktop Environment :: Window Managers :: Oroborus',
    'Desktop Environment :: Window Managers :: Oroborus :: Themes',
    'Desktop Environment :: Window Managers :: Sawfish',
    'Desktop Environment :: Window Managers :: Sawfish :: Themes 0.30',
    'Desktop Environment :: Window Managers :: Sawfish :: Themes pre-0.30',
    'Desktop Environment :: Window Managers :: Waimea',
    'Desktop Environment :: Window Managers :: Waimea :: Themes',
    'Desktop Environment :: Window Managers :: Window Maker',
    'Desktop Environment :: Window Managers :: Window Maker :: Applets',
    'Desktop Environment :: Window Managers :: Window Maker :: Themes',
    'Desktop Environment :: Window Managers :: XFCE',
    'Desktop Environment :: Window Managers :: XFCE :: Themes',
    'Documentation',
    'Documentation :: Sphinx',
    'Education',
    'Education :: Computer Aided Instruction (CAI)',
    'Education :: Testing',
    'File Formats',
    'File Formats :: JSON',
    'File Formats :: JSON :: JSON Schema',
    'Games/Entertainment',
    'Games/Entertainment :: Arcade',
    'Games/Entertainment :: Board Games',
    'Games/Entertainment :: First Person Shooters',
    'Games/Entertainment :: Fortune Cookies',
    'Games/Entertainment :: Multi-User Dungeons (MUD)',
    'Games/Entertainment :: Puzzle Games',
    'Games/Entertainment :: Real Time Strategy',
    'Games/Entertainment :: Role-Playing',
    'Games/Entertainment :: Side-Scrolling/Arcade Games',
    'Games/Entertainment :: Simulation',
    'Games/Entertainment :: Turn Based Strategy',
    'Home Automation',
    'Internet',
    'Internet :: File Transfer Protocol (FTP)',
    'Internet :: Finger',
    'Internet :: Log Analysis',
    'Internet :: Name Service (DNS)',
    'Internet :: Proxy Servers',
    'Internet :: WAP',
    'Internet :: WWW/HTTP',
    'Internet :: WWW/HTTP :: Browsers',
    'Internet :: WWW/HTTP :: Dynamic Content',
    'Internet :: WWW/HTTP :: Dynamic Content :: CGI Tools/Libraries',
    'Internet :: WWW/HTTP :: Dynamic Content :: Content Management System',
    'Internet :: WWW/HTTP :: Dynamic Content :: Message Boards',
    'Internet :: WWW/HTTP :: Dynamic Content :: News/Diary',
    'Internet :: WWW/HTTP :: Dynamic Content :: Page Counters',
    'Internet :: WWW/HTTP :: Dynamic Content :: Wiki',
    'Internet :: WWW/HTTP :: HTTP Servers',
    'Internet :: WWW/HTTP :: Indexing/Search',
    'Internet :: WWW/HTTP :: Session',
    'Internet :: WWW/HTTP :: Site Management',
    'Internet :: WWW/HTTP :: Site Management :: Link Checking',
    'Internet :: WWW/HTTP :: WSGI',
    'Internet :: WWW/HTTP :: WSGI :: Application',
    'Internet :: WWW/HTTP :: WSGI :: Middleware',
    'Internet :: WWW/HTTP :: WSGI :: Server',
    'Internet :: XMPP',
    'Internet :: Z39.50',
    'Multimedia',
    'Multimedia :: Graphics',
    'Multimedia :: Graphics :: 3D Modeling',
    'Multimedia :: Graphics :: 3D Rendering',
    'Multimedia :: Graphics :: Capture',
    'Multimedia :: Graphics :: Capture :: Digital Camera',
    'Multimedia :: Graphics :: Capture :: Scanners',
    'Multimedia :: Graphics :: Capture :: Screen Capture',
    'Multimedia :: Graphics :: Editors',
    'Multimedia :: Graphics :: Editors :: Raster-Based',
    'Multimedia :: Graphics :: Editors :: Vector-Based',
    'Multimedia :: Graphics :: Graphics Conversion',
    'Multimedia :: Graphics :: Presentation',
    'Multimedia :: Graphics :: Viewers',
    'Multimedia :: Sound/Audio',
    'Multimedia :: Sound/Audio :: Analysis',
    'Multimedia :: Sound/Audio :: CD Audio',
    'Multimedia :: Sound/Audio :: CD Audio :: CD Playing',
    'Multimedia :: Sound/Audio :: CD Audio :: CD Ripping',
    'Multimedia :: Sound/Audio :: CD Audio :: CD Writing',
    'Multimedia :: Sound/Audio :: Capture/Recording',
    'Multimedia :: Sound/Audio :: Conversion',
    'Multimedia :: Sound/Audio :: Editors',
    'Multimedia :: Sound/Audio :: MIDI',
    'Multimedia :: Sound/Audio :: Mixers',
    'Multimedia :: Sound/Audio :: Players',
    'Multimedia :: Sound/Audio :: Players :: MP3',
    'Multimedia :: Sound/Audio :: Sound Synthesis',
    'Multimedia :: Sound/Audio :: Speech',
    'Multimedia :: Video',
    'Multimedia :: Video :: Capture',
    'Multimedia :: Video :: Conversion',
    'Multimedia :: Video :: Display',
    'Multimedia :: Video :: Non-Linear Editor',
    'Office/Business',
    'Office/Business :: Financial',
    'Office/Business :: Financial :: Accounting',
    'Office/Business :: Financial :: Investment',
    'Office/Business :: Financial :: Point-Of-Sale',
    'Office/Business :: Financial :: Spreadsheet',
    'Office/Business :: Groupware',
    'Office/Business :: News/Diary',
    'Office/Business :: Office Suites',
    'Office/Business :: Scheduling',
    'Other/Nonlisted Topic',
    'Printing',
    'Religion',
    'Scientific/Engineering',
    'Scientific/Engineering :: Artificial Intelligence',
    'Scientific/Engineering :: Artificial Life',
    'Scientific/Engineering :: Astronomy',
    'Scientific/Engineering :: Atmospheric Science',
    'Scientific/Engineering :: Bio-Informatics',
    'Scientific/Engineering :: Chemistry',
    'Scientific/Engineering :: Electronic Design Automation (EDA)',
    'Scientific/Engineering :: GIS',
    'Scientific/Engineering :: Human Machine Interfaces',
    'Scientific/Engineering :: Hydrology',
    'Scientific/Engineering :: Image Processing',
    'Scientific/Engineering :: Image Recognition',
    'Scientific/Engineering :: Information Analysis',
    'Scientific/Engineering :: Interface Engine/Protocol Translator',
    'Scientific/Engineering :: Mathematics',
    'Scientific/Engineering :: Medical Science Apps.',
    'Scientific/Engineering :: Oceanography',
    'Scientific/Engineering :: Physics',
    'Scientific/Engineering :: Visualization',
    'Security',
    'Security :: Cryptography',
    'Sociology',
    'Sociology :: Genealogy',
    'Sociology :: History',
    'Software Development',
    'Software Development :: Assemblers',
    'Software Development :: Bug Tracking',
    'Software Development :: Build Tools',
    'Software Development :: Code Generators',
    'Software Development :: Compilers',
    'Software Development :: Debuggers',
    'Software Development :: Disassemblers',
    'Software Development :: Documentation',
    'Software Development :: Embedded Systems',
    'Software Development :: Internationalization',
    'Software Development :: Interpreters',
    'Software Development :: Libraries',
    'Software Development :: Libraries :: Application Frameworks',
    'Software Development :: Libraries :: Java Libraries',
    'Software Development :: Libraries :: PHP Classes',
    'Software Development :: Libraries :: Perl Modules',
    'Software Development :: Libraries :: Pike Modules',
    'Software Development :: Libraries :: Python Modules',
    'Software Development :: Libraries :: Ruby Modules',
    'Software Development :: Libraries :: Tcl Extensions',
    'Software Development :: Libraries :: pygame',
    'Software Development :: Localization',
    'Software Development :: Object Brokering',
    'Software Development :: Object Brokering :: CORBA',
    'Software Development :: Pre-processors',
    'Software Development :: Quality Assurance',
    'Software Development :: Testing',
    'Software Development :: Testing :: Acceptance',
    'Software Development :: Testing :: BDD',
    'Software Development :: Testing :: Mocking',
    'Software Development :: Testing :: Traffic Generation',
    'Software Development :: Testing :: Unit',
    'Software Development :: User Interfaces',
    'Software Development :: Version Control',
    'Software Development :: Version Control :: Bazaar',
    'Software Development :: Version Control :: CVS',
    'Software Development :: Version Control :: Git',
    'Software Development :: Version Control :: Mercurial',
    'Software Development :: Version Control :: RCS',
    'Software Development :: Version Control :: SCCS',
    'Software Development :: Widget Sets',
    'System',
    'System :: Archiving',
    'System :: Archiving :: Backup',
    'System :: Archiving :: Compression',
    'System :: Archiving :: Mirroring',
    'System :: Archiving :: Packaging',
    'System :: Benchmark',
    'System :: Boot',
    'System :: Boot :: Init',
    'System :: Clustering',
    'System :: Console Fonts',
    'System :: Distributed Computing',
    'System :: Emulators',
    'System :: Filesystems',
    'System :: Hardware',
    'System :: Hardware :: Hardware Drivers',
    'System :: Hardware :: Mainframes',
    'System :: Hardware :: Symmetric Multi-processing',
    'System :: Hardware :: Universal Serial Bus (USB)',
    'System :: Hardware :: Universal Serial Bus (USB) :: Audio',
    'System :: Hardware :: Universal Serial Bus (USB) :: Audio/Video (AV)',
    'System :: Hardware :: Universal Serial Bus (USB) :: Communications Device Class (CDC)',
    'System :: Hardware :: Universal Serial Bus (USB) :: Diagnostic Device',
    'System :: Hardware :: Universal Serial Bus (USB) :: Hub',
    'System :: Hardware :: Universal Serial Bus (USB) :: Human Interface Device (HID)',
    'System :: Hardware :: Universal Serial Bus (USB) :: Mass Storage',
    'System :: Hardware :: Universal Serial Bus (USB) :: Miscellaneous',
    'System :: Hardware :: Universal Serial Bus (USB) :: Printer',
    'System :: Hardware :: Universal Serial Bus (USB) :: Smart Card',
    'System :: Hardware :: Universal Serial Bus (USB) :: Vendor',
    'System :: Hardware :: Universal Serial Bus (USB) :: Video (UVC)',
    'System :: Hardware :: Universal Serial Bus (USB) :: Wireless Controller',
    'System :: Installation/Setup',
    'System :: Logging',
    'System :: Monitoring',
    'System :: Networking',
    'System :: Networking :: Firewalls',
    'System :: Networking :: Monitoring',
    'System :: Networking :: Monitoring :: Hardware Watchdog',
    'System :: Networking :: Time Synchronization',
    'System :: Operating System',
    'System :: Operating System Kernels',
    'System :: Operating System Kernels :: BSD',
    'System :: Operating System Kernels :: GNU Hurd',
    'System :: Operating System Kernels :: Linux',
    'System :: Power (UPS)',
    'System :: Recovery Tools',
    'System :: Shells',
    'System :: Software Distribution',
    'System :: System Shells',
    'System :: Systems Administration',
    'System :: Systems Administration :: Authentication/Directory',
    'System :: Systems Administration :: Authentication/Directory :: LDAP',
    'System :: Systems Administration :: Authentication/Directory :: NIS',
    'Terminals',
    'Terminals :: Serial',
    'Terminals :: Telnet',
    'Terminals :: Terminal Emulators/X Terminals',
    'Text Editors',
    'Text Editors :: Documentation',
    'Text Editors :: Emacs',
    'Text Editors :: Integrated Development Environments (IDE)',
    'Text Editors :: Text Processing',
    'Text Editors :: Word Processors',
    'Text Processing',
    'Text Processing :: Filters',
    'Text Processing :: Fonts',
    'Text Processing :: General',
    'Text Processing :: Indexing',
    'Text Processing :: Linguistic',
    'Text Processing :: Markup',
    'Text Processing :: Markup :: HTML',
    'Text Processing :: Markup :: LaTeX',
    'Text Processing :: Markup :: Markdown',
    'Text Processing :: Markup :: SGML',
    'Text Processing :: Markup :: VRML',
    'Text Processing :: Markup :: XML',
    'Text Processing :: Markup :: reStructuredText',
    'Utilities',
]



# noqa: INP001
# Copyright 2023 Ross J. Duff MSc
# The copyright holder licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at

#   http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
"""python template: check core metadata"""
import os
import pathlib

#
import tomli

# pylint: disable=consider-using-with
source = pathlib.Path(
    os.path.relpath(
        os.path.join('/', os.environ.get('MESON_SOURCE_ROOT', os.path.relpath('..'))), '/'
    )
)
project_file = open(source / 'pyproject.toml', 'rb')
pyproject_toml = tomli.load(project_file)
project_file.close()
core_metadata = pyproject_toml.get('project', {'optional_dependencies': {}})
print(core_metadata.get('optional_dependencies', {'todo': []}).get('@0@', 'fail'))
